#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 27-May-2003
#################################################################################
#
# Proto - Script that will create useful database dumps.
# Copyright (C) 2000-2003  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204 - 817, 5th Street NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################

use strict;							# Strict variable enforcement

use eRealms::Database;						# Database handler


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle

my $res;							# Result handle
my $statement;							# Query

#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$database = new eRealms::Database();

	# Connect and Fetch
	$database->Connect();

	#
	#
	# Contacts
	$database->Pull(\$statement, "SELECT
		  ContactName      AS \"ContactName\",
		  ContactType      AS \"ContactType\",
		  ContactFilter    AS \"ContactFilter\"
		FROM ethereal.Contact
		ORDER BY ContactType, ContactName");

	# Title
	print "--\n-- CONTACT\n--\n";

	# Loop and display
	while ($res = $statement->fetchrow_hashref())
	{
		# Display
		printf "INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES(%s,%s,%s);\n",
			Format($res->{'ContactName'}),
			Format($res->{'ContactType'}),
			Format($res->{'ContactFilter'});
	}

	# End
	$statement->finish();


	#
	#
	# Font
	$database->Pull(\$statement, "SELECT
		  FontName         AS \"FontName\",
		  FontType         AS \"FontType\",
		  FontCode         AS \"FontCode\"
		FROM ethereal.Font
		ORDER BY FontType, FontName");

	# Title
	print "\n\n--\n-- FONT\n--\n";

	# Loop and display
	while ($res = $statement->fetchrow_hashref())
	{
		# Display
		printf "INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES(%s,%s,%s);\n",
			Format($res->{'FontName'}),
			Format($res->{'FontType'}),
			Format($res->{'FontCode'});
	}

	# End
	$statement->finish();


	#
	#
	# Fortunes
	$database->Pull(\$statement, "SELECT
		  FortuneType      AS \"FortuneType\",
		  FortuneMsg       AS \"FortuneMsg\"
		FROM ethereal.Fortune
		WHERE FortuneMsg IS NOT NULL
		ORDER BY FortuneType");

	# Title
	print "\n\n--\n-- FORTUNES\n--\n";

	# Loop and display
	while ($res = $statement->fetchrow_hashref())
	{
		# Display
		printf "INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES(%s,%s);\n",
			Format($res->{'FortuneType'}),
			Format($res->{'FortuneMsg'});
	}

	# End
	$statement->finish();


	#
	#
	# Genre
	$database->Pull(\$statement, "SELECT
		  GenreName        AS \"GenreName\",
		  GenreOrder       AS \"GenreOrder\",
		  GenreDescription AS \"GenreDescription\"
		FROM ethereal.Genre
		ORDER BY GenreOrder, GenreName");

	# Title
	print "\n\n--\n-- GENRE\n--\n";

	# Loop and display
	while ($res = $statement->fetchrow_hashref())
	{
		# Display
		printf "INSERT INTO ethereal.Genre (GenreName,GenreOrder,GenreDescription) VALUES(%s,%s,%s);\n",
			Format($res->{'GenreName'}),
			Format($res->{'GenreOrder'}),
			Format($res->{'GenreDescription'});
	}

	# End
	$statement->finish();


	#
	#
	# Gummies
	$database->Pull(\$statement, "SELECT
		  GummyName        AS \"GummyName\",
		  GummyClass       AS \"GummyClass\",
		  GummyPath        AS \"GummyPath\",
		  GummyIdent       AS \"GummyIdent\"
		FROM ethereal.Gummy
		WHERE RealmName=?
		ORDER BY GummyCLass, GummyName", 'system');

	# Title
	print "\n\n--\n-- GUMMY\n--\n";

	# Loop and display
	while ($res = $statement->fetchrow_hashref())
	{
		# Display
		printf "INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent) VALUES(%s,%s,%s,%s);\n",
			Format($res->{'GummyName'}),
			Format($res->{'GummyClass'}),
			Format($res->{'GummyPath'}),
			Format($res->{'GummyIdent'});
	}

	# End
	$statement->finish();


	#
	#
	# Tags
	$database->Pull(\$statement, "SELECT
		  TagName       AS \"TagName\",
		  TagType       AS \"TagType\",
		  TagData       AS \"TagData\"
		FROM ethereal.Tag
		WHERE NOT (TagName ILIKE 'SetDonations%'
		  AND TagType=?)
		  AND NOT (TagName ILIKE 'SetKey%'
		  AND TagType=?)
		  AND NOT (TagName ILIKE '%Donation'
		  AND TagType=?)
		ORDER BY TagType, TagName", 

	 'system',
	 'system',
	 'template'
	);

	# Title
	print "\n\n--\n-- TAG\n--\n";

	# Loop and display
	while ($res = $statement->fetchrow_hashref())
	{
		# Display
		printf "INSERT INTO ethereal.Gummy (TagName,TagType,TagData) VALUES(%s,%s,%s);\n",
			Format($res->{'TagName'}),
			Format($res->{'TagType'}),
			Format($res->{'TagData'});
	}

	# End
	$statement->finish();


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Data Format
#
# Will make sure to return things properly for use in the display.   Otherwise
# things may not work as expected.

sub Format
{
	#####################
	# Data members

	my $data    = shift;					# Piece to check 


	#####################
	# Program area

	# Defined
	if (defined($data))
	{
		# Format cleanly
		$data =~ s/(\'|\"|\`)/\\$1/gs;
		$data =~ s/\n/\\n/gs;
		$data =~ s/\r/\\r/gs;
		$data =~ s/\\/\\/gs;

		# Release renames
		$data =~ s/(erealms|ethereal-realms)/acme/gsi;
		$data =~ s/(Ethereal Realms|Ethereal)/Acme Chat/gsi;

		# Location
		$data =~ s/Alberta/SomeState/gsi;
		$data =~ s/Calgary/SomeVille/gsi;
		$data =~ s/Canada/Somewhere/gsi;


		# Return
		return "'$data'";
	}

	# Nulls
	else
	{
		# Null value
		return 'NULL';
	}
}
